@@ -20,9 +20,9 @@ sub calculate {
 	my $l = length(@Pointxyz); 
 
 	while (--$l >= 0) {
-		$p->setx($p->getx + @Bin[$l]*@Pointxyz[$l]);
-		$p->sety($p->gety + @Bin[$l]*@Pointxyz[$l]);
-		$p->setz($p->getz + @Bin[$l]*@Pointxyz[$l]);
+		$p->setx($p->getx + @Bin[$l]*@Pointxyz[0]);
+		$p->sety($p->gety + @Bin[$l]*@Pointxyz[1]);
+		$p->setz($p->getz + @Bin[$l]*@Pointxyz[2]);
 	}
 
 	return $p;
@@ -36,7 +36,7 @@ sub calculate_for_z_order {
 	my $l = length(@Pointxyz); 
 
 	while (--$l >= 0) {
-		$z += @Bin[$l]*@Pointzyz[$l];
+		$z += @Bin[$l]*@Pointzyz[2];
 	}
 
 	return $z;
